import os
from pyramid.threadlocal import get_current_request
from pyramid_layout.panel import panel_config
from pyramid.events import NewRequest
from pyramid.events import subscriber
from .message import MessageQueue


@panel_config(name='flash_message', renderer='pyramid_flash_message:flash_message.jinja2')
def flash_message(context, request):
    return {}

@subscriber(NewRequest)
def add_message(event):
    request = event.request
    message_queue = MessageQueue(request=request)
    request.message_queue = message_queue



from pyramid.threadlocal import get_current_request

class MessageQueue():
    danger = 'danger'
    warning = 'warning'
    info = 'info'
    success = 'success'

    def __init__(self, body='', message_type=info, source='', mapping={}, **kwargs):
        self.type = message_type
        self.body = body
        self.source = source
        self.mapping = mapping


        if not (source or body):
            self.body = 'no notice found'
            self.type = MessageQueue.info

    def add(self, body, message_type=None, source=None, mapping=None, **kwargs):
        if message_type:
            self.type = message_type
        if source:
            self.source = source
        if mapping:
            self.mapping = mapping
        self.body = body

        # TODO: check if message queue is full

        self.request.session.flash({"type": self.type, 'source': self.source, 'body': self.body, 'mapping': self.mapping})



    def __repr__(self):
        request = get_current_request()
        user = request.authenticated_userid
        return 'source:{0} ip:{4} type:{1} user:{2} message:{3}'.format(
            self.source,
            self.type,
            user,
            (self.body, self.mapping),
            (lambda x : x.remote_addr if x else '')(request)
        )

    def __str__(self):
        return self.__repr__()



import os

from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.rst')) as f:
    README = f.read()

requires = [
    'pyramid',
    'pyramid_jinja2',
    'pyramid_layout',
    ]


setup(name='pyramid_flash_message',
      version='0.1.1',
      description='Small tool to add and show flash messages',
      long_description=README,
      classifiers=[
          "Programming Language :: Python",
          "Framework :: Pyramid",
          "Topic :: Internet :: WWW/HTTP",
          "Topic :: Internet :: WWW/HTTP :: WSGI :: Application",
      ],
      author='Sayyid Hamid Mahdavi',
      author_email='sayyid.hamid.mahdavi@gmail.com',
      url='https://github.com/sahama/pyramid_flash_message',
      keywords='web wsgi bfg pylons pyramid flash message',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      extras_require={},
      install_requires=requires,
      )
